
import java.util.*;

/**
 *
 * @author Anat Schloss
 */
public class FileReader
{

    private java.util.Scanner reader;

    /**
     * Constructs a new FileReader that reads values from the specified file.
     * @param pathname - pathname string of the file.
     */
    public FileReader(String pathname)
    {
        try
        {
            reader = new java.util.Scanner(new java.io.File(pathname));
        }
        catch (java.io.FileNotFoundException ex)
        {
            System.out.println(ex.getMessage());
        }
    }

    /**
     * Read int value from the file.
     * @return int value read from the file
     */
    public int readInt()
    {
        return reader.nextInt();
    }

    /**
     * Read double value from the file.
     * @return double value read from the file
     */
    public double readDouble()
    {
        return reader.nextDouble();
    }

    /**
     * Read boolean value from the file.
     * @return boolean value read from the file
     */
    public boolean readBoolean()
    {
        return reader.nextBoolean();
    }

    /**
     * Read char value from the file.
     * @return char value read from the file
     */
    public char readChar()
    {
        return reader.next().charAt(0);
    }

    /**
     * Read String value from the file.
     * @return String value read from the file
     */
    public String readString()
    {
        return reader.next();
    }

    /**
     * Read the current line of the file.
     * @return String value representing  the current line of the file
     */
    public String readLine()
    {
        String line = reader.nextLine();
        if (line.equals(""))
        {
            return reader.nextLine();
        }
        return line;
    }

    /**
     * Read array of int values from the file.
     * @return array of int values read from the file
     */
    public int[] readIntArray()
    {
        ArrayList<Integer> list = new ArrayList<Integer>();
        reader.next(); //"["
        while (reader.hasNextInt())
        {
            list.add(reader.nextInt());
        }
        reader.next(); //"]"
        //throw new InputMismatchException();

        int[] arr = new int[list.size()];
        for (int i = 0; i < arr.length; i++)
        {
            arr[i] = list.get(i);
        }
        return arr;


    }

    /**
     * Read matrix of int values from the file.
     * @return matrix of int values read from the file
     */
    public int[][] readIntMatrix()
    {
        ArrayList<ArrayList<Integer>> matLst = new ArrayList<ArrayList<Integer>>();

        reader.next();//"["
        while (reader.hasNext("\\["))
        {
            reader.next(); //"["
            ArrayList<Integer> row = new ArrayList<Integer>();
            while (reader.hasNextInt())
            {
                row.add(reader.nextInt());
            }
            reader.next(); //"]"
            matLst.add(row);
        }
        reader.next(); //"]"
        //throw new InputMismatchException();

        int[][] mat = new int[matLst.size()][];
        for (int i = 0; i < mat.length; i++)
        {
            mat[i] = new int[matLst.get(i).size()];
            for (int j = 0; j < mat[i].length; j++)
            {
                mat[i][j] = matLst.get(i).get(j);
            }
        }
        return mat;
    }

    /**
     * Read array of double values from the file.
     * @return array of double values read from the file
     */
    public double[] readDoubleArray()
    {
        ArrayList<Double> list = new ArrayList<Double>();
        reader.next(); //"["
        while (reader.hasNextDouble())
        {
            list.add(reader.nextDouble());
        }
        reader.next(); //"]"
        //throw new InputMismatchException();

        double[] arr = new double[list.size()];
        for (int i = 0; i < arr.length; i++)
        {
            arr[i] = list.get(i);
        }
        return arr;
    }

    /**
     * Read array of String values from the file.
     * @return array of String values read from the file
     */
    public String[] readStringArray()
    {
        ArrayList<String> list = new ArrayList<String>();
        reader.next(); //"["
        while (!reader.hasNext("]"))
        {
            list.add(reader.next());
        }
        reader.next(); //"]"
        //throw new InputMismatchException();

        String[] arr = new String[list.size()];
        return list.toArray(arr);
    }

    /**
     * Closes the FileReader
     */
    public void close()
    {
        reader.close();        
    }

    @Override
    protected void finalize() throws Throwable
    {
        try
        {            
            this.close();
        }
        finally
        {
            super.finalize();
        }
    }
}
