
import java.io.IOException;


/**
 *
 * @author Anat Schloss
 */
public class FileWriter
{

    private java.io.FileWriter writer;

    /**
     * Constructs a new FileWriter that writes values to the specified file.
     * @param pathname - pathname string of the file.
     */
    public FileWriter(String pathname)
    {
        try
        {
            writer = new java.io.FileWriter(pathname);
        }
        catch (java.io.IOException ex)
        {
            System.out.println(ex.getMessage());
        }
    }   

    /**
     * Write int value to the file.
     * @param value - int value to be written to the file
     */
    public void writeInt(int value)
    {
        try
        {
            writer.write(Integer.toString(value));
            writer.write('\n');
            writer.flush();
        }
        catch (java.io.IOException ex)
        {
            System.out.println(ex.getMessage());
        }
    }

    /**
     * Write double value to the file.
     * @param value - double value to be written to the file
     */
    public void writeDouble(double value)
    {
        try
        {
            writer.write(Double.toString(value));
            writer.write('\n');
            writer.flush();
        }
        catch (java.io.IOException ex)
        {
            System.out.println(ex.getMessage());
        }
    }

    /**
     * Write boolean value to the file.
     * @param value - boolean value to be written to the file
     */
    public void writeBoolean(boolean value)
    {
        try
        {
            writer.write(Boolean.toString(value));
            writer.write('\n');
            writer.flush();
        }
        catch (java.io.IOException ex)
        {
            System.out.println(ex.getMessage());
        }
    }

    /**
     * Write char value to the file.
     * @param value - char value to be written to the file
     */
    public void writeChar(char value)
    {
        try
        {
            writer.write(Character.toString(value));
            writer.write('\n');
            writer.flush();
        }
        catch (java.io.IOException ex)
        {
            System.out.println(ex.getMessage());
        }
    }

    /**
     * Write String value to the file.
     * @param value - String value to be written to the file
     */
    public void writeString(String value)
    {
        try
        {
            writer.write(value);
            writer.write('\n');
            writer.flush();
        }
        catch (java.io.IOException ex)
        {
            System.out.println(ex.getMessage());
        }
    }

    /**
     * Write array of int values to the file.
     * @param arr - array of int values value to be written to the file
     */
    public void writeIntArray(int[] arr)
    {
        try
        {
            StringBuilder str = new StringBuilder();
            str.append("[");
            for (int num : arr)
            {
                str.append(" ").append(num).append(" ");
            }
            str.append("]");
            writer.write(str.toString());
            writer.write('\n');
            writer.flush();
        }
        catch (java.io.IOException ex)
        {
            System.out.println(ex.getMessage());
        }
    }

    /**
     * Write matrix of int values to the file.
     * @param mat - matrix of int values to be written to the file
     */
    public void writeIntMatrix(int[][] mat)
    {
        try
        {
            StringBuilder str = new StringBuilder();
            str.append("[");
            for (int[] arr : mat)
            {
                str.append(" [ ");
                for (int num : arr)
                {
                    str.append(" ").append(num).append(" ");
                }
                str.append(" ] ");
            }
            str.append("]");
            writer.write(str.toString());
            writer.write('\n');
            writer.flush();
        }
        catch (java.io.IOException ex)
        {
            System.out.println(ex.getMessage());
        }
    }

    /**
     * Write array of double values to the file.
     * @param arr - array of double values to be written to the file
     */
    public void writeDoubleArray(double[] arr)
    {
        try
        {
            StringBuilder str = new StringBuilder();
            str.append("[");
            for (double num : arr)
            {
                str.append(" ").append(num).append(" ");
            }
            str.append("]");
            writer.write(str.toString());
            writer.write('\n');
            writer.flush();
        }
        catch (java.io.IOException ex)
        {
            System.out.println(ex.getMessage());
        }
    }

    /**
     * Write array of String values to the file.
     * @param arr - array of String values to be written to the file
     */
    public void writeStringArray(String[] arr)
    {
        try
        {
            StringBuilder str = new StringBuilder();
            str.append("[");
            for (String s : arr)
            {
                str.append(" ").append(s).append(" ");
            }
            str.append("]");
            writer.write(str.toString());
            writer.write('\n');
            writer.flush();
        }
        catch (java.io.IOException ex)
        {
            System.out.println(ex.getMessage());
        }
    }

    /**
     * Closes the FileWriter
     */
    public void close()
    {
        try
        {
            writer.close();            
        }
        catch (IOException ex)
        {
            System.out.println(ex.getMessage());
        }
    }

    @Override
    protected void finalize() throws Throwable
    {
        try
        {            
            this.close();
        }
        finally
        {
            super.finalize();
        }
    }
}
